'use client'

import React from 'react'
import { motion } from 'framer-motion'

interface ProcessStepProps {
  number: number
  title: string
  description: string
  color: string
}

const processSteps: ProcessStepProps[] = [
  {
    number: 1,
    title: "Discovery and Assessment",
    description: "We dive deep to understand your needs and challenges to deliver tailored solutions.",
    color: "bg-pink-400"
  },
  {
    number: 2,
    title: "Information Gathering and Analysis",
    description: "We collect relevant data and analyze the best possible approaches to drive results.",
    color: "bg-orange-400"
  },
  {
    number: 3,
    title: "Implementation and Testing",
    description: "We ensure a seamless deployment and thoroughly test the solution to guarantee success.",
    color: "bg-green-400"
  }
]

const ProcessStep: React.FC<ProcessStepProps> = ({ number, title, description, color }) => {
  return (
    <motion.div 
      className="ops-process-step bg-white rounded-lg shadow-lg p-6 relative"
      initial={{ opacity: 0, y: 50 }}
      whileInView={{ opacity: 1, y: 0 }}
      viewport={{ once: true }}
      transition={{ duration: 0.5 }}
      whileHover={{ scale: 1.05 }}
    >
      <div className={`ops-process-bar absolute top-0 left-0 right-0 h-2 bg-gradient-to-r from-pink-400 to-yellow-400 rounded-t-lg`}></div>
      <div className={`ops-process-number ${color} text-white rounded-full w-12 h-12 flex items-center justify-center text-xl font-bold mb-4`}>
        {number}
      </div>
      <h3 className="ops-process-title text-xl font-bold mb-2">{title}</h3>
      <p className="ops-process-description text-gray-600">{description}</p>
    </motion.div>
  )
}

const OurProcessSection: React.FC = () => {
  return (
    <section className="ops-section bg-gray-100 py-16 px-4">
      <div className="ops-container max-w-6xl mx-auto">
        <motion.h2 
          className="ops-title text-4xl md:text-5xl font-bold text-center mb-4"
          initial={{ opacity: 0, y: -20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.5 }}
        >
          <span className="ops-title-text bg-clip-text text-transparent bg-gradient-to-r from-pink-500 to-orange-500">
            Our Process
          </span>
        </motion.h2>
        <motion.p 
          className="ops-subtitle text-center text-gray-600 mb-12"
          initial={{ opacity: 0, y: -20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.5, delay: 0.2 }}
        >
          Follow our streamlined process for optimal results in just three simple steps.
        </motion.p>
        <div className="ops-process-grid grid grid-cols-1 md:grid-cols-3 gap-8">
          {processSteps.map((step, index) => (
            <ProcessStep key={index} {...step} />
          ))}
        </div>
      </div>
    </section>
  )
}

export default OurProcessSection